@@ -2,6 +2,7 @@ from djraphql.django_models import get_target_field
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from ...mappings import Types
 from graphene import Field, InputObjectType, List
+from graphql import Undefined
 
 
 class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -27,7 +28,8 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                         registry.get_or_create_type(
                             Types.NESTED_ITEM_INSERT_TYPE,
                             model_class=field.related_model,
-                        )
+                        ),
+                        default_value=Undefined,
                     )
             elif field.many_to_one or field.one_to_one:
                 related_entity = registry.get_entity_class(field.related_model)
@@ -44,7 +46,9 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     graphene_type = registry.get_graphene_type_or_default(
                         reverse_model_field
                     )
-                    input_class_attrs["{}_id".format(field.name)] = graphene_type()
+                    input_class_attrs["{}_id".format(field.name)] = graphene_type(
+                        default_value=Undefined
+                    )
 
                 # Check that the related object type is creatable and if it is, allow
                 # a nested create by defining the related model's insert input type.
@@ -52,7 +56,8 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     input_class_attrs[field.name] = Field(
                         registry.lambda_from_registry(
                             field.related_model, Types.INSERT_INPUT_TYPE
-                        )
+                        ),
+                        default_value=Undefined,
                     )
             elif field.many_to_many:
                 pass
@@ -64,12 +69,17 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     choices=field.choices,
                 )
                 input_class_attrs[field.name] = Field(
-                    enum_type, required=not field.null and field.default is None
+                    enum_type,
+                    required=not field.null and field.default is None,
+                    default_value=Undefined,
                 )
             else:
                 input_class_attrs[field.name] = registry.get_graphene_type_or_default(
                     model_field
-                )(required=not field.null and not field.has_default())
+                )(
+                    required=not field.null and not field.has_default(),
+                    default_value=Undefined,
+                )
 
         return type(
             "{}Input".format(model_class.__name__),
