@@ -1,6 +1,7 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from ...mappings import Types
 from graphene import Field, InputObjectType, String
+from graphql import Undefined
 
 
 class NestedItemInsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -13,10 +14,11 @@ class NestedItemInsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
             "NestedItemInsert{}".format(model_class.__name__),
             (InputObjectType,),
             {
-                "tag": Field(String),
+                "tag": Field(String, default_value=Undefined),
                 "data": Field(
                     registry.lambda_from_registry(model_class, Types.INSERT_INPUT_TYPE),
                     required=True,
+                    default_value=Undefined,
                 ),
             },
         )
