@@ -2,6 +2,7 @@ from djraphql.django_models import get_target_field
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from ...mappings import Types
 from graphene import Field, InputObjectType
+from graphql import Undefined
 
 
 class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -43,14 +44,18 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     graphene_type = registry.get_graphene_type_or_default(
                         reverse_model_field
                     )
-                    input_class_attrs["{}_id".format(field.name)] = graphene_type()
+                    input_class_attrs["{}_id".format(field.name)] = graphene_type(
+                        default_value=Undefined
+                    )
                 continue
 
             if field.one_to_many:
                 list_update_input_type = registry.get_or_create_type(
                     Types.LIST_UPDATE_INPUT_TYPE, model_class=field.related_model
                 )
-                input_class_attrs[field.name] = Field(list_update_input_type)
+                input_class_attrs[field.name] = Field(
+                    list_update_input_type, default_value=Undefined
+                )
             elif field.many_to_one or field.one_to_one:
                 if field.concrete:
                     reverse_model_field = registry.get_model_fields(
@@ -60,12 +65,15 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     graphene_type = registry.get_graphene_type_or_default(
                         reverse_model_field
                     )
-                    input_class_attrs["{}_id".format(field.name)] = graphene_type()
+                    input_class_attrs["{}_id".format(field.name)] = graphene_type(
+                        default_value=Undefined
+                    )
                 related_model = field.related_model
                 input_class_attrs[field.name] = Field(
                     registry.lambda_from_registry(
                         related_model, Types.UPDATE_INPUT_TYPE
-                    )
+                    ),
+                    default_value=Undefined,
                 )
             elif field.many_to_many:
                 pass
@@ -76,11 +84,13 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     field=field,
                     choices=field.choices,
                 )
-                input_class_attrs[field.name] = Field(enum_type, required=False)
+                input_class_attrs[field.name] = Field(
+                    enum_type, required=False, default_value=Undefined
+                )
             else:
                 input_class_attrs[field.name] = registry.get_graphene_type_or_default(
                     model_field
-                )()
+                )(default_value=Undefined)
 
         return type(
             "{}UpdateInput".format(model_class.__name__),
