@@ -1,6 +1,6 @@
-from graphql.language.visitor import Visitor
+from graphql.language.visitor import Visitor, SKIP, IDLE
 from graphene import Union
-from graphene.utils.str_converters import to_snake_case
+from graphene.utils.str_converters import to_snake_case, to_camel_case
 from djraphql.django_models import get_field_by_name
 from graphql.execution.values import get_argument_values
 
@@ -39,7 +39,7 @@ class QueryFieldsVisitor(Visitor):
         # If the query contains GraphQL-spec-level fields like __typename,
         # field_def will be None here. We can ignore when this happens.
         if field_def is None and node.name.value in IGNORED_FIELDS:
-            return
+            return SKIP
 
         arguments = get_argument_values(
             field_def,
@@ -56,21 +56,21 @@ class QueryFieldsVisitor(Visitor):
             else:
                 # The associated model doesn't have a field with the same name.
                 # The only possibility is that this field corresponds to a ComputedField.
-                # If this ComputedField defined a depends_on list, we process it here.
                 entity_class = self.type_lookup[parent_gql_type.name]["entity_class"]
-                for computed_field in entity_class._get_computed_fields():
-
-                    # If we run into a Union type as a ComputedField, just skip this
-                    # because it's impossible to optimize the associated subtree.
-                    if is_union_type(computed_field.graphene_type):
-                        return False
-
+                computed_field = entity_class._get_computed_field(
+                    lambda field: node.name.value == to_camel_case(field.name)
+                )
+                if computed_field:
+                    # Tell the Django ORM to fetch dependency fields
                     for dependency in computed_field.depends_on:
                         field = try_get_related_field(model_class, dependency)
                         if field:
                             self.hello_field(field, arguments, graphql_node=node)
                             self.goodbye_field(field)
 
+                    # Don't traverse into ComputedFields
+                    return SKIP
+
         # If we're traversing a relationship (e.g., we're entering the
         # "artists" node within the "LabelsMany" query), we need to push the new
         # GraphQLTypeObject class and model class onto their respective stacks.
@@ -125,7 +125,7 @@ class QueryFieldsVisitor(Visitor):
                 )
                 if field:
                     self.goodbye_field(field)
-            return
+            return IDLE
 
         # We are not traversing a relationship. If we have a non-empty
         # model stack, we need to call the goodbye_field handler.
@@ -146,11 +146,6 @@ def get_terminal_gql_type(gql_type):
     return gql_type
 
 
-def is_union_type(gql_type):
-    terminal_type = get_terminal_gql_type(gql_type)
-    return isinstance(terminal_type, type) and issubclass(terminal_type, Union)
-
-
 def try_get_related_field(model_class, selection_name):
     names_to_try = [
         # First try just getting the field from the model via the selection's name
